#!/bin/bash

SCRIPT_DIR=$(cd "$(dirname "${BASH_SOURCE[0]}")" && pwd)

if [[ -z "${SCRIPT_DIR}" ]]; then
    echo "Script dir not present"
    exit 1
fi

#shellcheck disable=SC1090,SC1091
source "${SCRIPT_DIR}/utils.sh"

function test_credential_creation() {
    if pwsh "${SCRIPT_DIR}/../pipeline/Pipeline_Tests/Test-CredentialCreation.ps1";
    then
        mark_test_passed 1526395 /tmp/test_results.json
    else
        mark_test_failed 1526395 /tmp/test_results.json
    fi
}

function test_ceph_upload() {
    ceph_fqdn=$(kubectl -n istio-system get vs cephobjectstore-vs -o json | jq '.spec.hosts[0]' | xargs)
    ceph_port=443
    printf '{"ceph_fqdn":"%s","ceph_external_port":"%s"}\n' "${ceph_fqdn}" "${ceph_port}" > required_input.json

    if pwsh "${SCRIPT_DIR}/../pipeline/Pipeline_Tests/Test-CEPH.ps1" -ConfigFilePath required_input.json;
    then
        mark_test_passed 1623525 /tmp/test_results.json
    else
        mark_test_failed 1623525 /tmp/test_results.json
    fi
}

function main() {
    bash "${SCRIPT_DIR}/validate-argocd.sh"
    test_credential_creation
    test_ceph_upload
}

main
