#!/bin/bash

SCRIPT_DIR=$(cd "$(dirname "${BASH_SOURCE[0]}")" && pwd)

if [[ -z "${SCRIPT_DIR}" ]]; then
    echo "Script dir not present"
    exit 1
fi

#shellcheck disable=SC1090,SC1091
source "${SCRIPT_DIR}/utils.sh"

export KUBECONFIG=/etc/rancher/rke2/rke2.yaml PATH=$PATH:/var/lib/rancher/rke2/bin

function login_argocd() {
  input=$(cat /opt/UiPathAutomationSuite/UiPath_Installer/input.json)
  # Login argocd
  argo_password="$(kubectl -n argocd get secrets argocd-admin-password -o jsonpath={.data.password} | base64 -d)"
  fqdn=$(jq -r ".fqdn" /opt/UiPathAutomationSuite/UiPath_Installer/merged_input.json)
  argo_subdomain=$(jq -r ".subdomain.argo_cd" /opt/UiPathAutomationSuite/UiPath_Installer/merged_input.json)
  argo_port=$(jq -r ".cluster_port" /opt/UiPathAutomationSuite/UiPath_Installer/merged_input.json)          
  /opt/UiPathAutomationSuite/UiPath_Installer/bin/argocd login "${argo_subdomain}.${fqdn}:${argo_port}" --grpc-web --grpc-web-root-path "/" --username admin --password "${argo_password}" --insecure
}

function change_sync_policy() {
  /opt/UiPathAutomationSuite/UiPath_Installer/bin/argocd app set fabric-configure --sync-policy "$1"
  /opt/UiPathAutomationSuite/UiPath_Installer/bin/argocd app set rancher-monitoring --sync-policy "$1"  
}

function modify_alert_config() {
  kubectl get prometheusrule rancher-monitoring-kubernetes-system-kubelet -n cattle-monitoring-system -o json | jq '(.spec.groups[0].rules[] | select(.alert == "KubeNodeNotReady") | .for) |= "0m"' | kubectl replace -f -
  kubectl get prometheusrule internode-communication-broken -n uipath-infra -o json | jq '(.spec.groups[0].rules[] | select(.alert == "InternodeCommunicationBroken") | .for) |= "0m"' | kubectl replace -f -
}

function setMonitoringValidationParam() {
    local validationStage
    validationStage=$1
    
    case "$validationStage" in
    3nodeup|rebootAllServers|1nodeup|0nodeup)
        SKIP_NODE_DOWN_TEST="true"
        ;;
    2nodeup)
        SKIP_NODE_DOWN_TEST="false"
        ;;
    *)
        echo "Unexpected option ${validationStage} passed to ${FUNCNAME[0]}"
        exit 1
        ;;
    esac
}

function executeNodeDownTest() {
  setMonitoringValidationParam "${VALIDATE_STAGE}"
  
  if [[ "${SKIP_NODE_DOWN_TEST}" == "false" ]]; then
    login_argocd
    change_sync_policy "none"
    modify_alert_config
    
    [[ "$(is_alert_fired "KubeNodeNotReady" "server1" ".labels.node")" == "true" ]] && appendOutput "1661202" "true" || appendOutput "1661202" "false"
    [[ "$(is_alert_fired "InternodeCommunicationBroken" "server0" ".labels.goldpinger_instance")" == "true" ]] && appendOutput "1661358" "true" || appendOutput "1661358" "false"
    [[ "$(is_alert_fired "MongodbReplicationStatusUnreachable" "" "")" == "true" ]] && appendOutput "1888841" "true" || appendOutput "1888841" "false"
    change_sync_policy "automated"
  fi
}